/*_############################################################################
  _##
  _##  SNMP4J - TlsX509CertifiedTarget.java
  _##
  _##  Copyright (C) 2003-2019  Frank Fock and Jochen Katz (SNMP4J.org)
  _##
  _##  Licensed under the Apache License, Version 2.0 (the "License");
  _##  you may not use this file except in compliance with the License.
  _##  You may obtain a copy of the License at
  _##
  _##      http://www.apache.org/licenses/LICENSE-2.0
  _##
  _##  Unless required by applicable law or agreed to in writing, software
  _##  distributed under the License is distributed on an "AS IS" BASIS,
  _##  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  _##  See the License for the specific language governing permissions and
  _##  limitations under the License.
  _##
  _##########################################################################*/

package org.snmp4j.transport.tls;

import org.snmp4j.CertifiedTarget;
import org.snmp4j.smi.Address;
import org.snmp4j.smi.OctetString;

import java.security.cert.X509Certificate;

/**
 * The {@code TlsCertifiedTarget} extends the {@link org.snmp4j.CertifiedTarget} class by means to provide
 * a {@link TlsTmSecurityCallback} reference directly with the target as needed according to RFC 6353 §5.3.1 when
 * establishing a connection based on the SNMP-TARGET-MIB as client.
 *
 * @author Frank Fock
 * @since 3.2.3
 */
public class TlsX509CertifiedTarget<A extends Address> extends CertifiedTarget<A> {

    private static final long serialVersionUID = -1980959130605037036L;
    private TlsTmSecurityCallback<X509Certificate> tlsTmSecurityCallback;

    public TlsX509CertifiedTarget(A address, OctetString identity,
                              OctetString serverFingerprint, OctetString clientFingerprint,
                              TlsTmSecurityCallback<X509Certificate> tlsTmSecurityCallback) {
        super(address, identity, serverFingerprint, clientFingerprint);
        if (tlsTmSecurityCallback == null) {
            throw new NullPointerException("TlsTmSecurityCallback must not be null for TlsCertifiedTarget");
        }
        this.tlsTmSecurityCallback = tlsTmSecurityCallback;
    }

    /**
     * Gets the {@link TlsTmSecurityCallback} information needed to validate a client-server connection.
     * @return a {@link TlsTmSecurityCallback} instance or {@code null} if such information is not provided then
     * the transport mapping has to block (drop) the connection creation.
     */
    public TlsTmSecurityCallback<X509Certificate> getTlsTmSecurityCallback() {
        return tlsTmSecurityCallback;
    }
}
